package com.diagbot.util;

import com.diagbot.biz.push.entity.Lis;
import com.diagbot.dto.BillMsg;
import com.diagbot.dto.RuleSimpleDTO;
import com.diagbot.enums.ConEnum;
import com.diagbot.enums.RedisEnum;
import com.diagbot.enums.TypeEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @description: 提示语工具类
 * @author: zhoutg
 * @time: 2020/9/14 11:16
 */
@Component
public class MsgNewUtil {

    @Autowired
    RedisUtil redisUtil;

    /**
     * 开单合理性通用提示信息
     *
     * @param ruleSimpleDTO
     * @return
     */
    public BillMsg getCommonBillMsg(RuleSimpleDTO ruleSimpleDTO) {
        String orderName = ruleSimpleDTO.getInputName(); // 医院名称
        String orderStandName = ruleSimpleDTO.getLibName(); // 标准名称
        String orderType = ruleSimpleDTO.getLibTypeName(); // 开单项类型
        String content = ruleSimpleDTO.getContent(); // 界面匹配内容
        String conType = ruleSimpleDTO.getConType(); // 禁忌类型
        String unionMsg = ruleSimpleDTO.getMsg(); // 原因及建议
        String structName = ruleSimpleDTO.getStructName(); // 项目名称
        String msg = redisUtil.getByKeyAndField(RedisEnum.msg.getName(), orderType + "_" + conType);
        if (StringUtil.isBlank(msg)) {
            // msg = redisUtil.getByKeyAndField(RedisEnum.msg.getName(), "通用" + "_" + "默认提示语");
            msg = "";
        }
        BillMsg billMsg = new BillMsg();
        // 出现2个“具有”，去除一个为空
        if (ConEnum.medEqu.getName().equals(conType) && StringUtil.isNotBlank(content)
                && content.startsWith("具有") && msg.startsWith("该患者具有")) {
            msg = msg.replaceAll("具有", "");
        }
        if (StringUtil.isNotBlank(unionMsg)) {
            msg = msg.replaceAll("\\[原因及建议]", "，" + unionMsg);
        } else {
            msg = msg.replaceAll("\\[原因及建议]", "");
        }
        // [性别取反]标签替换
        if (ConEnum.gender.getName().equals(conType)) {
            if ("男".equals(content)) {
                msg = msg.replaceAll("\\[性别取反]", "女");
            } else if ("女".equals(content)) {
                msg = msg.replaceAll("\\[性别取反]", "男");
            }
        }

        // 放到最后统一替换【多处匹配】
        msg = msg.replaceAll("\\[匹配内容]", content);
        String orderNameNew = orderName.replaceAll("\\\\","\\\\\\\\"); // 防止开单名称中有\\
        msg = msg.replaceAll("\\[开单名称]", orderNameNew);
        msg = msg.replaceAll("\\[项目名称]", structName);
        billMsg.setMsg(msg);
        billMsg.setOrderName(orderName);
        billMsg.setOrderStandName(orderStandName);
        billMsg.setContent(content);
        billMsg.setType(conType);
        return billMsg;
    }

    /**
     * 其他值通用提示信息
     *
     * @param content
     * @param name
     * @param type
     * @param lis
     * @param suggestMsg
     * @return
     */
    public BillMsg getCommonOtherMsg(String otherType, String content, String name, String type, Lis lis, String suggestMsg, String lisNameDetail) {
        BillMsg billMsg = new BillMsg();
        String msg = "";
        switch (TypeEnum.getEnum(otherType)) {
            case lis: // 其他值提醒——化验
                msg = redisUtil.getByKeyAndField(RedisEnum.otherMsg.getName(), otherType + "_" + type);
                if (StringUtil.isBlank(msg)) { // 防止报空指针
                    return null;
                }
                if (StringUtil.isNotBlank(suggestMsg)) {
                    msg = msg.replaceAll("\\[原因及建议]", "，" + suggestMsg);
                } else {
                    msg = msg.replaceAll("\\[原因及建议]", "");
                }
                // 放到最后统一替换【多处匹配】
                msg = msg.replaceAll("\\[化验结果]", content);
                msg = msg.replaceAll("\\[匹配内容]", name);
                if (msg.contains("[化验套餐和明细]")) {
                    msg = msg.replaceAll("\\[化验套餐和明细]", lisNameDetail);
                }
                billMsg.setType(type);
                billMsg.setOrderName(lis.getName());
                billMsg.setOrderDetailName(lis.getDetailName());
                break;
            default:
                break;
        }
        billMsg.setMsg(msg);
        billMsg.setContent(content);
        return billMsg;
    }

    /**
     * 危急值化验提示信息
     *
     * @param type 分类
     * @param content 化验内容
     * @param name 条件内容
     * @param conditionType 条件类型
     * @param suggestMsg
     * @return
     */
    public BillMsg getCriticalMsg(String type, String content, String name, String conditionType, String suggestMsg) {
        BillMsg billMsg = new BillMsg();
        String msg = "";
        switch (TypeEnum.getEnum(type)) {
            case lis: // 危急值提醒——化验
                msg = redisUtil.getByKeyAndField(RedisEnum.criticalMsg.getName(), type + "_" + conditionType);
                if (StringUtil.isBlank(msg)) { // 防止报空指针
                    return null;
                }
                if (StringUtil.isNotBlank(suggestMsg)) {
                    msg = msg.replaceAll("\\[原因及建议]", "，" + suggestMsg);
                } else {
                    msg = msg.replaceAll("\\[原因及建议]", "");
                }
                // 放到最后统一替换【多处匹配】
                msg = msg.replaceAll("\\[化验结果]", content);
                msg = msg.replaceAll("\\[匹配内容]", name);
                billMsg.setType(conditionType);
                break;
            default:
                break;
        }
        billMsg.setMsg(msg);
        billMsg.setContent(content);
        return billMsg;
    }
}
